-- Talent check file for the shaman class
local class = "SHAMAN";

-- set up check table
ScrubFork.checks = ScrubFork.checks or { };
ScrubFork.checks[class] = ScrubFork.checks[class] or { };

-- simple function to create new checks
local function check(name, severity, check)
	tinsert(ScrubFork.checks[class], {name=name, severity=severity, check=check});
end

local GREEN = ScrubFork.GREEN;
local YELLOW = ScrubFork.YELLOW;
local RED = ScrubFork.RED;

-- Meta
check("Partial Elemental Spec",			YELLOW,	function (talents) return (talents:spent(1) >= 21) and (talents:spent(1) < 41); end);
check("Partial Enhancement Spec",		YELLOW,	function (talents) return (talents:spent(2) >= 21) and (talents:spent(2) < 41); end);
check("Partial Restoration Spec",		YELLOW,	function (talents) return (talents:spent(3) >= 21) and (talents:spent(3) < 41); end);
check("Elemental with Enhance Talents",	RED,	function (talents) return (talents:spent(1) >= 21) and (talents:spent(2) >  5); end);
check("Enhance with Elemental Talents", RED,	function (talents) return (talents:spent(2) >= 21) and (talents:spent(1) >  5); end);
check("Resto with Enhance Talents",		RED,	function (talents) return (talents:spent(3) >= 21) and (talents:spent(2) >  5); end);
check("Elemental Filler Talents",		RED,	function (talents) return (talents:spent(1) >= 21) and (talents:rank(1, 7) + talents:rank(1, 10) > 1); end);
check("Resto with Nature's Guidance",	RED,	function (talents) return (talents:spent(3) >= 21) and (talents:rank(3,  6) > 0); end);

-- Elemental
check("Lacking Convection",				RED,	function (talents) return (talents:spent(1) >= 21) and (talents:rank(1,  1) < 5); end);
check("Lacking Concussion",				RED,	function (talents) return (talents:spent(1) >= 21) and (talents:rank(1,  2) < 5); end);
check("Earth's Grasp",					RED,	function (talents) return talents:rank(1,  3) > 0; end);
check("Call of Flame",					RED,	function (talents) return talents:rank(1,  5) > 0; end);
check("No Elemental Focus",				RED,	function (talents) return (talents:spent(1) >= 11) and (talents:rank(1,  6) < 1); end);
check("Reverberation (PvP)",			YELLOW,	function (talents) return talents:rank(1,  7) > 1; end);
check("Lacking Call of Thunder",		RED,	function (talents) return (talents:spent(1) >= 16) and (talents:rank(1,  8) < 5); end);
check("Improved Fire Nova Totem",		RED,	function (talents) return talents:rank(1,  9) > 0; end);
check("Eye of the Storm (PvP)",			YELLOW,	function (talents) return talents:rank(1, 10) > 1; end);
check("Elemental Devastation",			RED,	function (talents) return talents:rank(1, 11) > 0; end);
check("No Storm Reach",					YELLOW,	function (talents) return (talents:spent(1) >= 23) and (talents:rank(1, 12) < 2); end);
check("No Elemental Fury",				RED,	function (talents) return (talents:spent(1) >= 21) and (talents:rank(1, 13) < 1); end);
check("Lacking Unrelenting Storm",		YELLOW,	function (talents) return (talents:spent(1) >= 35) and (talents:rank(1, 14) < 3); end);
check("Lacking Elemental Precision",	RED,	function (talents) return (talents:spent(1) >= 34) and (talents:rank(1, 15) < 3); end);
check("Lacking Lightning Mastery",		RED,	function (talents) return (talents:spent(1) >= 30) and (talents:rank(1, 16) < 5); end);
check("No Elemental Mastery",			YELLOW,	function (talents) return (talents:spent(1) >= 31) and (talents:rank(1, 17) < 1) and (talents:rank(1, 14) < 4); end);
check("Elemental Shields (PvP)",		RED,	function (talents) return talents:rank(1, 18) > 0; end);
check("Lacking Lightning Overload",		RED,	function (talents) return (talents:spent(1) >= 40) and (talents:rank(1, 19) < 5); end);
check("No Totem of Wrath",				RED,	function (talents) return (talents:spent(1) >= 41) and (talents:rank(1, 20) < 1); end);

-- Enhancement
check("Shield Specialization",			RED,	function (talents) return talents:rank(2,  2) > 0; end);
check("No Thundering Strikes",			RED,	function (talents) return (talents:spent(2) >= 10) and (talents:rank(2,  4) < 5); end);
check("Improved Lightning Shield (PvP)",YELLOW,	function (talents) return talents:rank(2,  6) > 0; end);
check("Lacking Enhancing Totems",		RED,	function (talents) return (talents:spent(2) >= 13) and (talents:rank(2,  7) < 2); end);
check("No Shamanistic Focus",			RED,	function (talents) return (talents:spent(2) >= 11) and (talents:rank(2,  8) < 1); end);
check("Anticipation (PvP)",				RED,	function (talents) return talents:rank(2,  9) > 2; end);
check("Lacking Flurry",					RED,	function (talents) return (talents:spent(2) >= 20) and (talents:rank(2, 10) < 5); end);
check("Toughness (PvP)",				RED,	function (talents) return talents:rank(2, 11) > 0; end);
check("Lacking Improved Weapon Totems",	RED,	function (talents) return (talents:spent(2) >= 26) and (talents:rank(2, 12) < 2); end);
check("No Spirit Weapons",				RED,	function (talents) return (talents:spent(2) >= 21) and (talents:rank(2, 13) < 1); end);
check("Lacking Elemental Weapons",		RED,	function (talents) return (talents:spent(2) >= 24) and (talents:rank(2, 14) < 3); end);
check("Lacking Mental Quickness",		YELLOW,	function (talents) return (talents:spent(2) >= 41) and (talents:rank(2, 15) < 3); end);
check("Lacking Weapon Mastery",			RED,	function (talents) return (talents:spent(2) >= 30) and (talents:rank(2, 16) < 5); end);
check("No Stormstrike",					RED,	function (talents) return (talents:spent(2) >= 31) and (talents:rank(2, 19) < 1); end);
check("No Dual Wield",					RED,	function (talents) return (talents:spent(2) >= 31) and (talents:rank(2, 18) < 1); end);
check("Lacking Dual Wield Spec.",		YELLOW,	function (talents) return (talents:rank(2, 18) > 0) and (talents:rank(2, 17) < 3); end);
check("Lacking Unleashed Rage",			RED,	function (talents) return (talents:spent(2) >= 40) and (talents:rank(2, 20) < 5); end);
check("No Shamanistic Rage",			YELLOW,	function (talents) return (talents:spent(2) >= 41) and (talents:rank(2, 21) < 1); end);

-- Restoration
check("Lacking Improved Healing Wave",	RED,	function (talents) return (talents:spent(3) >= 21) and (talents:rank(3,  1) < 5); end);
check("Lacking Tidal Focus",			RED,	function (talents) return (talents:spent(3) >= 21) and (talents:rank(3,  2) < 5); end);
check("Ancestral Healing without T.M.",	YELLOW,	function (talents) return (talents:rank(3, 4) > 0) and (talents:rank(3, 11) < 5); end);
check("No Totemic Mastery",				RED,	function (talents) return talents:rank(3, 8) < 1; end);
check("Lacking Restorative Totems",		RED,	function (talents) return (talents:spent(3) >= 21) and (talents:rank(3, 10) < 4); end);
check("Lacking Tidal Mastery",			YELLOW,	function (talents) return (talents:rank(1, 14) > 0) and (talents:rank(3, 11) < 8 - talents:rank(1, 14)); end);
check("Lacking Healing Way",			YELLOW,	function (talents) return (talents:spent(3) >= 24) and (talents:rank(3, 12) < 3); end);
check("No Nature's Swiftness",			RED,	function (talents) return (talents:spent(3) >= 21) and (talents:rank(3, 13) < 1); end);
check("Lacking Purification",			RED,	function (talents) return (talents:spent(3) >= 30) and (talents:rank(3, 15) < 5); end);
check("No Mana Tide Totem",				RED,	function (talents) return (talents:spent(3) >= 31) and (talents:rank(3, 16) < 1); end);
check("Lacking Improved Chain Heal",	RED,	function (talents) return (talents:spent(3) >= 37) and (talents:rank(3, 19) < 2); end);
check("No Earth Shield",				RED,	function (talents) return (talents:spent(3) >= 41) and (talents:rank(3, 20) < 1); end);
